==> moodle_1.3.1.orig.tar.gz: moodle/lang/pl/editor.php <==
<?PHP // $Id: editor.php,v 1.4 2004/04/09 19:18:34 adamtpaw Exp $ 
      // editor.php - created with Moodle 1.2.1 beta (2004032200)


$string['about'] = 'O tym edytorze';
$string['absbottom'] = 'D';
$string['absmiddle'] = 'rodek';
$string['address'] = 'Adres';
$string['alignment'] = 'Justowanie';
$string['alternatetext'] = 'Tekst alternatywny';
$string['baseline'] = 'Dolna linia';
$string['bold'] = 'Czcionka pogrubiona';
$string['borderthickness'] = 'Grubo ramki';
$string['bottom'] = 'D';
$string['browse'] = 'Przegldaj';
$string['cancel'] = 'Anuluj';
$string['cellpadding'] = 'Marginesy wewntrz komrki';
$string['cellspacing'] = 'Marginesy dookoa komrki';
$string['choosechar'] = 'Wybierz liter';
$string['chooseicon'] = 'Wybierz ikon do wstawienia';
$string['close'] = 'Zamknij';
$string['cols'] = 'Kolumny';
$string['copy'] = 'Skopiuj zaznaczone';
$string['createfolder'] = 'Utwrz folder';
$string['createlink'] = 'Wstaw link';
$string['cut'] = 'Wytnij zaznaczone';
$string['delete'] = 'Usu';
$string['filebrowser'] = 'Przejrzyj pliki';
$string['forecolor'] = 'Kolor czcionki';
$string['heading'] = 'Nagwek';
$string['height'] = 'Wysoko';
$string['hilitecolor'] = 'Kolor ta';
$string['horizontal'] = 'Poziome';
$string['horizontalrule'] = 'Linia horyzontalna';
$string['htmlmode'] = 'Przecz na kod HTML';
$string['imageurl'] = 'URL do obrazka';
$string['indent'] = 'Zwiksz indent';
$string['insertchar'] = 'Wstaw specjaln liter';
$string['insertimage'] = 'Wstaw zdjcie';
$string['insertlink'] = 'Wstaw link';
$string['insertsmile'] = 'Wstaw ikonk (smiley)';
$string['inserttable'] = 'Wstaw tabel';
$string['italic'] = 'Kursywa';
$string['justifycenter'] = 'Wyrodkuj tekst';
$string['justifyfull'] = 'Pene justowanie';
$string['justifyleft'] = 'Wyrwnaj do lewej';
$string['justifyright'] = 'Wyrwnaj do prawej';
$string['layout'] = 'Ukad';
$string['left'] = 'Lewo';
$string['linkproperties'] = 'Waciwoci linku';
$string['linktarget'] = 'Cel';
$string['linktargetblank'] = 'Nowe okno';
$string['linktargetnone'] = 'adne';
$string['linktargetother'] = 'Inne (nieuporzdkowane)';
$string['linktargetself'] = 'Ta sama ramka';
$string['linktargettop'] = 'To samo okno';
$string['linktitle'] = 'Tytu';
$string['linkurl'] = 'URL';
$string['middle'] = 'rodek';
$string['move'] = 'Przesu';
$string['normal'] = 'Normalne';
$string['notimage'] = 'Wybrany plik nie jest zdjciem! Prosz wska zdjcie.';
$string['notset'] = 'Nie ustawione';
$string['ok'] = 'OK';
$string['orderedlist'] = 'Lista ponumerowana';
$string['outdent'] = 'Zmniejsz indent';
$string['paste'] = 'Wklej';
$string['path'] = 'cieka';
$string['percent'] = 'Procent';
$string['pixels'] = 'Piksele';
$string['popupeditor'] = 'Powiksz edytor';
$string['preformatted'] = 'Preformatowany';
$string['preview'] = 'Podgld';
$string['properties'] = 'Waciwoci';
$string['redo'] = 'Powtrz swoje ostatnie dziaanie';
$string['removelink'] = 'Usu link';
$string['rename'] = 'Zmie nazw';
$string['right'] = 'Prawo';
$string['rows'] = 'Rowki';
$string['selection'] = 'Zaznaczenie';
$string['showhelp'] = 'Pomoc';
$string['size'] = 'Rozmiar';
$string['spacing'] = 'Spacje';
$string['strikethrough'] = 'Literki z przeciciem';
$string['subscript'] = 'Indeks dolny';
$string['superscript'] = 'Indeks grny';
$string['textindicator'] = 'Aktualny styl';
$string['textmode'] = 'Jeste w trybie tekstowym. Uyj przyciskw [<>] aby wrci do trybu WYSIWYG.';
$string['texttop'] = 'Tekst na grze';
$string['top'] = 'Gra';
$string['type'] = 'Typ';
$string['underline'] = 'Podkrel';
$string['undo'] = 'Cofnij swoje ostatnie dziaanie';
$string['unorderedlist'] = 'Lista wypunktowana';
$string['upload'] = 'Przelij';
$string['vertical'] = 'Pionowe';
$string['width'] = 'Szeroko';
$string['zip'] = 'Skompresuj';

?>

==> moodle_1.4.4.dfsg.1.orig.tar.gz: moodle/lang/pl/editor.php <==
<?PHP // $Id$ 
      // editor.php - created with Moodle 1.4 (2004083100)


$string['about'] = 'O tym edytorze';
$string['absbottom'] = 'D';
$string['absmiddle'] = 'rodek';
$string['address'] = 'Adres';
$string['alignment'] = 'Justowanie';
$string['alternatetext'] = 'Tekst alternatywny';
$string['anchorhelp'] = 'Tworzy kotwic. Link i tak bdziesz musia utworzy rcznie.';
$string['anchorname'] = 'Nazwa ktowicy';
$string['anchors'] = 'Kotwice';
$string['baseline'] = 'Dolna linia';
$string['bold'] = 'Czcionka pogrubiona';
$string['borderthickness'] = 'Grubo ramki';
$string['bottom'] = 'D';
$string['browse'] = 'Przegldaj';
$string['cancel'] = 'Anuluj';
$string['cellpadding'] = 'Marginesy wewntrz komrki';
$string['cellspacing'] = 'Marginesy dookoa komrki';
$string['choosechar'] = 'Wybierz liter';
$string['chooseicon'] = 'Wybierz ikon do wstawienia';
$string['close'] = 'Zamknij';
$string['cols'] = 'Kolumny';
$string['copy'] = 'Skopiuj zaznaczone';
$string['createanchor'] = 'Stwrz kotwic';
$string['createfolder'] = 'Utwrz folder';
$string['createlink'] = 'Wstaw link';
$string['cut'] = 'Wytnij zaznaczone';
$string['delete'] = 'Usu';
$string['filebrowser'] = 'Przejrzyj pliki';
$string['forecolor'] = 'Kolor czcionki';
$string['fullscreen'] = 'Edytor penoekranowy';
$string['heading'] = 'Nagwek';
$string['height'] = 'Wysoko';
$string['hilitecolor'] = 'Kolor ta';
$string['horizontal'] = 'Poziome';
$string['horizontalrule'] = 'Linia horyzontalna';
$string['htmlmode'] = 'Przecz na kod HTML';
$string['imageurl'] = 'URL do obrazka';
$string['indent'] = 'Zwiksz indent';
$string['insertchar'] = 'Wstaw specjaln liter';
$string['insertimage'] = 'Wstaw zdjcie';
$string['insertlink'] = 'Wstaw link';
$string['insertsmile'] = 'Wstaw ikonk (smiley)';
$string['inserttable'] = 'Wstaw tabel';
$string['italic'] = 'Kursywa';
$string['justifycenter'] = 'Wyrodkuj tekst';
$string['justifyfull'] = 'Pene justowanie';
$string['justifyleft'] = 'Wyrwnaj do lewej';
$string['justifyright'] = 'Wyrwnaj do prawej';
$string['layout'] = 'Ukad';
$string['left'] = 'Lewo';
$string['lefttoright'] = 'Kierunek od lewej do prawej';
$string['linkproperties'] = 'Waciwoci linku';
$string['linktarget'] = 'Cel';
$string['linktargetblank'] = 'Nowe okno';
$string['linktargetnone'] = 'adne';
$string['linktargetother'] = 'Inne (nieuporzdkowane)';
$string['linktargetself'] = 'Ta sama ramka';
$string['linktargettop'] = 'To samo okno';
$string['linktitle'] = 'Tytu';
$string['linkurl'] = 'URL';
$string['middle'] = 'rodek';
$string['minimize'] = 'Minimalizuj edytor';
$string['move'] = 'Przesu';
$string['normal'] = 'Normalne';
$string['notimage'] = 'Wybrany plik nie jest zdjciem! Prosz wska zdjcie.';
$string['notset'] = 'Nie ustawione';
$string['ok'] = 'OK';
$string['orderedlist'] = 'Lista ponumerowana';
$string['outdent'] = 'Zmniejsz indent';
$string['paste'] = 'Wklej';
$string['path'] = 'cieka';
$string['percent'] = 'Procent';
$string['pixels'] = 'Piksele';
$string['popupeditor'] = 'Powiksz edytor';
$string['preformatted'] = 'Preformatowany';
$string['preview'] = 'Podgld';
$string['properties'] = 'Waciwoci';
$string['redo'] = 'Powtrz swoje ostatnie dziaanie';
$string['removelink'] = 'Usu link';
$string['rename'] = 'Zmie nazw';
$string['right'] = 'Prawo';
$string['righttoleft'] = 'Kierunek od prawej do lewej';
$string['rows'] = 'Rowki';
$string['selectcolor'] = 'Wybierz kolor';
$string['selection'] = 'Zaznaczenie';
$string['showhelp'] = 'Pomoc';
$string['size'] = 'Rozmiar';
$string['spacing'] = 'Spacje';
$string['strikethrough'] = 'Literki z przeciciem';
$string['subscript'] = 'Indeks dolny';
$string['superscript'] = 'Indeks grny';
$string['textindicator'] = 'Aktualny styl';
$string['textmode'] = 'Jeste w trybie tekstowym. Uyj przyciskw [<>] aby wrci do trybu WYSIWYG.';
$string['texttop'] = 'Tekst na grze';
$string['top'] = 'Gra';
$string['type'] = 'Typ';
$string['underline'] = 'Podkrel';
$string['undo'] = 'Cofnij swoje ostatnie dziaanie';
$string['unorderedlist'] = 'Lista wypunktowana';
$string['upload'] = 'Przelij';
$string['vertical'] = 'Pionowe';
$string['width'] = 'Szeroko';
$string['wordclean'] = 'Czysty HTML';
$string['zip'] = 'Skompresuj';

?>
